/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
#ifndef STATUS_NOTIFIER_COMMAND_H
#define STATUS_NOTIFIER_COMMAND_H

#include <string>

#include <boost/scoped_ptr.hpp>

//-----------------------------------------------------------------------------
// StatusNotifierCommand
//-----------------------------------------------------------------------------

/**
 * @brief This class provides methods to handle status-notifier-cmd
 * configuration.
 */
class StatusNotifierCommand
{
public:
    static const std::string StatusToken;

public:
    explicit StatusNotifierCommand( const std::string &status_notifier_cmd );
    virtual ~StatusNotifierCommand();

    bool set_token_value(
            const std::string &token,
            const std::string &value
    );

    bool execute() const;

private:
    std::string get_application_string() const;
    std::string get_arguments_string() const;

private:
    /// The command string used to notify the status
    std::string CommandStr;

    /// The original command before token replacement
    std::string CommandStrOriginal;

};

//-----------------------------------------------------------------------------
// StatusNotifierCommandItem
//-----------------------------------------------------------------------------

typedef boost::scoped_ptr<StatusNotifierCommand> StatusNotifierCommandItem;

#endif // STATUS_NOTIFIER_COMMAND_H
